@@ -247,3 +247,37 @@ class NavSoapClient():
 
         serialized_response = serialize_object(soap_response)
         return serialized_response
+
+
+    def create_site_location(self, cust_no, name, address, city, state, zip, county, lat, long, field_office_id, cust_resp_grp_id, name2=None, address2=None, lease_id=None, lease_name=None):
+        """
+        Create a Site in NAV.
+        """
+        session = Session()
+        session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
+
+        soap_service_url = self.nav_soap_service + \
+            self.nav_company + "/Codeunit/SiteManagementWS"
+        client = Client(soap_service_url, transport=Transport(
+            session=session, cache=SqliteCache()))
+
+        soap_response = client.service.CreateNewSite(
+                custNo=cust_no,
+                siteName=name,
+                siteName2=name2,
+                siteAddress=address,
+                siteAddress2=address2,
+                siteCity=city,
+                siteState=state,
+                siteZip=zip,
+                siteCounty=county,
+                leaseID=lease_id,
+                leaseName=lease_name,
+                siteLat=lat,
+                siteLong=long,
+                locationCode=field_office_id,
+                custRespGroup=cust_resp_grp_id
+        )
+
+        serialized_response = serialize_object(soap_response)
+        return serialized_response
\ No newline at end of file
